=== modified file 'bzrlib/info.py'
--- bzrlib/info.py	2011-11-08 01:13:38 +0000
+++ bzrlib/info.py	2011-11-08 01:23:39 +0000
@@ -343,9 +343,8 @@
             try:
                 repository = a_bzrdir.open_repository()
             except NoRepositoryPresent:
-                # Return silently; cmd_info already returned NotBranchError
-                # if no controldir could be opened.
-                return
+                lockable = None
+                repository = None
             else:
                 lockable = repository
         else:
@@ -356,12 +355,14 @@
         repository = branch.repository
         lockable = tree
 
-    lockable.lock_read()
+    if lockable is not None:
+        lockable.lock_read()
     try:
         show_component_info(a_bzrdir, repository, branch, tree, verbose,
                             outfile)
     finally:
-        lockable.unlock()
+        if lockable is not None:
+            lockable.unlock()
 
 
 def show_component_info(control, repository, branch=None, working=None,

=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2011-10-14 13:56:45 +0000
+++ bzrlib/tests/blackbox/test_info.py	2011-11-08 01:23:39 +0000
@@ -46,6 +46,15 @@
         self.assertEqual(out, '')
         self.assertEqual(err, 'bzr: ERROR: Not a branch: "%s".\n' % location)
 
+    def test_info_empty_controldir(self):
+        self.make_bzrdir('ctrl')
+        out, err = self.run_bzr('info ctrl')
+        self.assertEquals(out,
+            'Empty control directory (format: 1.14 or 1.14-rich-root or 2a or pack-0.92)\n'
+            'Location:\n'
+            '  control directory: ctrl\n')
+        self.assertEquals(err, '')
+
     def test_info_standalone(self):
         transport = self.get_transport()
 

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2011-11-01 23:06:12 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2011-11-08 01:23:39 +0000
@@ -52,6 +52,9 @@
 .. Fixes for situations where bzr would previously crash or give incorrect
    or undesirable results.
 
+* ``bzr info`` no longer shows empty output if only a control
+  directory is present. (Jelmer Vernooij, #159098)
+
 * ``bzr mkdir --quiet`` now does not print a line for every created
   directory. (Martin von Gagern, #869915)
 

